.. _2025-name:

!!!!
2025
!!!!

.. meta::
   :keywords: 2025,xrst,release,notes,for,mm-dd,12-28,09-19,08-19,08-18,08-15,08-04,07-19,06-12,05-26,05-25,05-11,04-17,03-13,03-07,02-18,02-15,02-03,01-24,01-11,01-10,01-05,01-04,01-03

.. index:: 2025, xrst, release, notes, 2025

.. _2025-title:

xrst Release Notes for 2025
###########################

.. contents::
   :local:

.. index:: mm-dd

.. _2025@mm-dd:

mm-dd
*****

.. _2025@mm-dd@12-28:

12-28
=====
Use the ``typos`` package to detect and correct spelling errors
in the source code comments and error messages.

.. _2025@mm-dd@09-19:

09-19
=====
In the ``bin/dev_settings.sh`` development tool, change `whee` to `where` .

.. _2025@mm-dd@08-19:

08-19
=====
In the ``bin/run_xrst.sh`` development tool,
change `python` to `python3` because this works on more systems.

.. _2025@mm-dd@08-18:

08-18
=====
In the `bin/dev_settings.sh` add the contributor_list setting
and use it in `bin/check_copy.sh` .
This handles the case where other user's (besides bradbell) are contributors.

.. _2025@mm-dd@08-15:

08-15
=====
In the ``bin/run_xrst.sh`` development tool,
when checking external links, change the timeout from 30 to 5 seconds.

.. _2025@mm-dd@08-04:

08-04
=====
In the ``bin/check_copy.sh`` development tool,
handle the case where a file has been deleted.

.. _2025@mm-dd@07-19:

07-19
=====
The ``bin/git_commit.sh`` development tools was modified to check
for spelling error in the commit log message (if typos is installed).

.. _2025@mm-dd@06-12:

06-12
=====
The ``bin/check_tab.sh`` development tool
was not properly handling files that were moved by git.
This has been fixed.

.. _2025@mm-dd@05-26:

05-26
=====
Fix some spellings errors in the development tool comments.

.. _2025@mm-dd@05-25:

05-25
=====
Make some minor improvements to the tools distributed by
``bin/dev_tools.sh`` .
To be more specific, handle some edge cases like there only
being one line to sort in a section of a file.

.. _2025@mm-dd@05-11:

05-11
=====
Do not include *text* in spell checking where *text*
is only letters and appears as either::

   \begin{text}
   \end{text}

This avoid spelling errors certain latex commands; for example::

   \begin{bmatrix}

.. _2025@mm-dd@04-17:

04-17
=====
#. Add python 3.13 to testing,
   drop python 3.8 from testing,
   and require python greater than or equal 3.9.
   (Python 3.13 release date, and 3.8 end of life date, is 2024-10-07.)

#. The Default branch for this repository what changed from master to main.

.. _2025@mm-dd@03-13:

03-13
=====
Detect and print an error message when the
start after line number plus one is greater than or equal
the end before line number.

.. _2025@mm-dd@03-07:

03-07
=====
There was a bug in the error message when a single or double quote was in the
output of the :ref:`config_file@input_files` command.
This has been fixed.

.. _2025@mm-dd@02-18:

02-18
=====
#. A :ref:`spell_cmd@spell_off` command would not be recognized
   if it was in the first line of a :ref:`template_cmd@template_file`  .
   This has been fixed.
   An example of spell_off in the first line of a template file
   was added under :ref:`example_expansion_one@This Template File`
   in the template example expansions.
#. The last entry in the list of :ref:`purpose@Features`
   on the purpose page was edited and moved to be the first entry.

.. _2025@mm-dd@02-15:

02-15
=====
Add the :ref:`run_xrst@link_timeout` command line option.

.. _2025@mm-dd@02-03:

02-03
=====
Add ``bin/group_list.sh``
and ``.readthedocs.yaml`` to the ``bin/dev_tools.sh`` development tools.

.. _2025@mm-dd@01-24:

01-24
=====
#. The template file item in the
   :ref:`wish_list@Spell Checking` wish list was removed
   because it was completed on
   :ref:`2024-10-25 <2024@mm-dd@10-25>` .
#. An external link item was added to the Spell Checking wish list.

.. _2025@mm-dd@01-11:

01-11
=====
Fix some problems when running xrst with
:ref:`run_xrst@target` equal to ``tex`` .

.. _2025@mm-dd@01-10:

01-10
=====
#. Include the :ref:`version <user-guide@Versions>` in this documentation.
#. Use the tomli package instead of the toml package; see
   `tomli <https://github.com/hukkin/tomli>`_ .

.. _2025@mm-dd@01-05:

01-05
=====
Conda Forge does not yet handle dependencies that are different for
different systems.
It was therefore decided to totally remove pyenchant
as a requirement when installing xrst.
In the same spirit, only the default html theme furo is a requirement.
If you use the pyenchant spell checker or one of the other themes,
and it is not installed, you will get a message suggesting that you install it.

.. _2025@mm-dd@01-04:

01-04
=====
1. Remove the pyenchant install requirement on windows; see
   :ref:`user-guide@Dependencies` .
2. Create the stable-2025 branch and its first release; see
   :ref:`user-guide@Versions` .

.. _2025@mm-dd@01-03:

01-03
=====
Improve the discussion of spelling errors in the
:ref:`get_started-name` example.
